@@ -6,7 +6,7 @@ from lamin_logger import logger
 from supabase import create_client
 from supabase.client import Client
 
-from ._settings import settings
+from ._settings_instance import InstanceSettings
 from ._settings_load import load_or_create_user_settings
 from ._settings_store import Connector, settings_dir
 
@@ -115,51 +115,51 @@ def sign_in_hub(email, password, handle=None):
 
 # can currently not type-annotate with lnschema_core.Storage as we cannot
 # import it statically at time of lndb_setup import
-def push_instance_if_not_exists(storage):
+def push_instance_if_not_exists(isettings: InstanceSettings, storage_db_entry):
     hub = connect_hub_with_auth()
 
-    response = hub.table("storage").select("*").eq("id", storage.id).execute()
+    owner = get_user_by_handle(hub, isettings.owner)
+
+    response = hub.table("storage").select("*").eq("id", storage_db_entry.id).execute()
     if len(response.data) == 0:
         storage_fields = {
-            "id": storage.id,
-            "root": str(storage.root),
-            "region": storage.region,
-            "type": storage.type,
+            "id": storage_db_entry.id,
+            "root": str(storage_db_entry.root),
+            "region": storage_db_entry.region,
+            "type": storage_db_entry.type,
         }
         data = hub.table("storage").insert(storage_fields).execute().data
         assert len(data) == 1
 
-    instance_info = get_instance_info(
-        hub, settings.instance.name, hub.auth.session().user.id.hex
-    )
-    if instance_info is None:
+    instance = get_instance(hub, isettings.name, owner["id"])
+    if instance is None:
         instance_fields = {
             "id": str(uuid.uuid4()),
-            "name": settings.instance.name,
-            "owner_id": hub.auth.session().user.id.hex,
-            "storage_id": storage.id,
-            "dbconfig": settings.instance._dbconfig,
-            "cache_dir": str(settings.instance.cache_dir),
-            "sqlite_file": str(settings.instance._sqlite_file),
-            "sqlite_file_local": str(settings.instance._sqlite_file_local),
-            "db": settings.instance.db,
+            "name": isettings.name,
+            "owner_id": owner["id"],
+            "storage_id": storage_db_entry.id,
+            "dbconfig": isettings._dbconfig,
+            "cache_dir": str(isettings.cache_dir),
+            "sqlite_file": str(isettings._sqlite_file),
+            "sqlite_file_local": str(isettings._sqlite_file_local),
+            "db": isettings.db,
         }
         data = hub.table("instance").insert(instance_fields).execute().data
         assert len(data) == 1
         instance_id = data[0]["id"]
     else:
-        instance_id = instance_info["id"]
+        instance_id = instance["id"]
 
     response = (
         hub.table("user_instance")
         .select("*")
-        .eq("user_id", hub.auth.session().user.id.hex)
+        .eq("user_id", owner["id"])
         .eq("instance_id", instance_id)
         .execute()
     )
     if len(response.data) == 0:
         user_instance_fields = {
-            "user_id": hub.auth.session().user.id.hex,
+            "user_id": owner["id"],
             "instance_id": instance_id,
         }
         data = hub.table("user_instance").insert(user_instance_fields).execute().data
@@ -168,7 +168,7 @@ def push_instance_if_not_exists(storage):
     hub.auth.sign_out()
 
 
-def get_instance_info(hub: Client, name: str, owner_id: str):
+def get_instance(hub: Client, name: str, owner_id: str):
     response = (
         hub.table("instance")
         .select("*")
@@ -187,7 +187,7 @@ def get_instance_info(hub: Client, name: str, owner_id: str):
     return instance
 
 
-def get_user_info_by_id(hub: Client, user_id: str):
+def get_user_by_id(hub: Client, user_id: str):
     response = hub.table("usermeta").select("*").eq("id", user_id).execute()
 
     if len(response.data) == 0:
@@ -200,7 +200,7 @@ def get_user_info_by_id(hub: Client, user_id: str):
     return usermeta
 
 
-def get_user_info_by_handle(hub: Client, handle: str):
+def get_user_by_handle(hub: Client, handle: str):
     response = hub.table("usermeta").select("*").eq("handle", handle).execute()
 
     if len(response.data) == 0:
