@@ -22,7 +22,7 @@ def check_migrate(
 ):
     if "LAMIN_SKIP_MIGRATION" in os.environ:
         if os.environ["LAMIN_SKIP_MIGRATION"] == "true":
-            return "migrate-failed"
+            return "migrate-skipped"
 
     status = []
     schema_names = ["core"] + list(isettings.schema)
